@@ -1,15 +1,15 @@
 context("Multiple registration")
 
 test_that("Multiple registration works", {
-    if (system.file(package="png") == "")
-        skip("The \"png\" package is not available")
+    if (system.file(package="loder") == "")
+        skip("The \"loder\" package is not available")
     else
     {
-        house <- png::readPNG(system.file("extdata","house.png",package="RNiftyReg"))
+        house <- loder::readPng(system.file("extdata","house.png",package="RNiftyReg"))
         affine <- buildAffine(skews=0.1, source=house, target=house)
         skewedHouse <- applyTransform(affine, house)
         
-        colourHouse <- png::readPNG(system.file("extdata","house_colour.png",package="RNiftyReg"))
+        colourHouse <- loder::readPng(system.file("extdata","house_colour.png",package="RNiftyReg"))
         skewedColourHouse <- applyTransform(affine, colourHouse)
         
         # Rec. 709 luma RGB-to-greyscale coefficients (as used by ImageMagick)
@@ -21,6 +21,7 @@ test_that("Multiple registration works", {
         expect_that(forward(reg)[1,2], equals(0.1,tolerance=0.05))
         
         skip_on_cran()
+        skip_on_travis()
         
         reg <- niftyreg(skewedColourHouse, house, scope="nonlinear", init=forward(reg), symmetric=FALSE, maxIterations=300)
         expect_that(dim(forward(reg)), equals(c(40L,56L,1L,1L,2L)))
